@@ -9,11 +9,18 @@ api = PushshiftAPI()
 def find_previous_get(comment, validate_get=True, verbosity=0):
     reddit = comment._reddit
     submission = comment.submission
-    url = next(filter(lambda x: int(x[0], 36) < int(submission.id, 36),
-                      parsing.find_urls_in_submission(submission)))
+    urls = filter(lambda x: int(x[0], 36) < int(submission.id, 36),
+                  parsing.find_urls_in_submission(submission))
+    url = next(urls)
 
     new_submission_id, new_get_id = url
-    if not new_get_id:
+    while not new_get_id:
+        try:
+            url = next(urls)
+            new_submission_id, new_get_id = url
+        except StopIteration:
+            break
+    if not new_get_id and validate_get:
         new_get_id = find_get_in_submission(new_submission_id, reddit)
     comment = reddit.comment(new_get_id)
     if validate_get:
@@ -26,9 +33,9 @@ def find_previous_get(comment, validate_get=True, verbosity=0):
     return new_get
 
 
-def find_get_in_submission(submission, reddit):
+def find_get_in_submission(submission_id, reddit):
     "Find the get based on submission id"
-    comment_ids = api._get_submission_comment_ids(submission.id)[::-1]
+    comment_ids = api._get_submission_comment_ids(submission_id)[::-1]
     for comment_id in comment_ids[:-1]:
         comment = reddit.comment(comment_id)
         try:
@@ -37,7 +44,7 @@ def find_get_in_submission(submission, reddit):
                 return comment.id
         except ValueError:
             continue
-    raise ValueError(f"Unable to locate get in submission {submission.id}")
+    raise ValueError(f"Unable to locate get in submission {submission_id}")
 
 
 def search_up_from_gz(comment, max_retries=5):
